@@ -5,7 +5,7 @@ import httpx
 import pytest
 from httpx import USE_CLIENT_DEFAULT
 
-from schema_registry.client import SchemaRegistryClient, schema, utils
+from schema_registry.client import Auth, SchemaRegistryClient, schema, utils
 from tests import data_gen
 
 
@@ -153,17 +153,12 @@ def test_basic_auth_user_info():
     assert response.request.headers.get("Authorization") == f"Basic {token}"
 
 
-def test_basic_auth_sasl_inherit():
-    username = "secret-user-sasl"
-    password = "secret-sasl"
+def test_auth():
+    username = "secret-user"
+    password = "secret"
     client = SchemaRegistryClient(
-        {
-            "url": "https://user_url:secret_url@127.0.0.1:65534",
-            "basic.auth.credentials.source": "SASL_INHERIT",
-            "sasl.mechanism": "PLAIN",
-            "sasl.username": username,
-            "sasl.password": password,
-        }
+        url="https://user_url:secret_url@127.0.0.1:65534",
+        auth=Auth(username=username, password=password),
     )
 
     userpass = b":".join((httpx._utils.to_bytes(username), httpx._utils.to_bytes(password)))
